.. _testing_module:

:mod:`pyramid.testing`
==========================

.. automodule:: pyramid.testing

  .. autofunction:: setUp

  .. autofunction:: tearDown

  .. autofunction:: testConfig(registry=None, request=None, hook_zca=True, autocommit=True, settings=None)

  .. autofunction:: cleanUp

  .. autoclass:: DummyResource
     :members:

  .. autoclass:: DummyRequest
     :members:

  .. autoclass:: DummyTemplateRenderer
     :members:



